@@ -16,12 +16,12 @@ impl RequestAnimationFrameHandle {
     /// Cancels an animation frame request.
     ///
     /// [(Javascript docs)](https://developer.mozilla.org/en-US/docs/Web/API/Window/cancelAnimationFrame)
-    pub fn cancel(self) {
-        js!{
-            var val = @{self.0};
+    pub fn cancel( self ) {
+        js! { @(no_return)
+            var val = @{&self.0};
             val.window.cancelAnimationFrame(val.request);
             val.callback.drop();
-        };
+        }
     }
 }
 
@@ -190,4 +190,27 @@ impl Window {
             return @{self}.outerHeight;
         ).try_into().unwrap()
     }
+
+    /// The read-only Window property pageYOffset is an alias for scrollY; as such, it returns
+    /// the number of pixels the document is currently scrolled along the vertical axis (that is,
+    /// up or down), with a value of 0.0 indicating that the top edge of the Document is currently
+    /// aligned with the top edge of the window's content area.
+    ///
+    /// [(JavaScript docs)](https://developer.mozilla.org/en-US/docs/Web/API/Window/pageYOffset)
+    // https://drafts.csswg.org/cssom-view/#ref-for-dom-window-pageyoffset
+    pub fn page_y_offset(&self) -> f64 {
+        js!(
+            return @{self}.pageYOffset;
+        ).try_into().unwrap()
+    }
+
+    /// This is an alias for scrollX.
+    ///
+    /// [(JavaScript docs)](https://developer.mozilla.org/en-US/docs/Web/API/Window/pageXOffset)
+    // https://drafts.csswg.org/cssom-view/#ref-for-dom-window-pagexoffset
+    pub fn page_x_offset(&self) -> f64 {
+        js!(
+            return @{self}.pageXOffset;
+        ).try_into().unwrap()
+    }
 }
